==> nextcloud-31.0.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/federation/l10n/ca.js <==
OC.L10N.register(
    "federation",
    {
    "Added to the list of trusted servers" : "S'ha afegit a la llista de servidors de confiança",
    "No server found with ID: %s" : "No s'ha trobat cap servidor amb ID: %s",
    "Could not remove server" : "No s'ha pogut eliminar el servidor",
    "Server is already in the list of trusted servers." : "El servidor ja es troba en la llista de servidors de confiança.",
    "No server to federate with found" : "No s'ha trobat cap servidor amb què federar-se",
    "Could not add server" : "No s'ha pogut afegir el servidor",
    "Trusted servers" : "Servidors de confiança",
    "Federation" : "Federació",
    "Federation allows you to connect with other trusted servers to exchange the account directory." : "La federació us permet connectar-vos amb altres servidors de confiança per a intercanviar la carpeta del compte.",
    "Federation allows you to connect with other trusted servers to exchange the account directory. For example this will be used to auto-complete external accounts for federated sharing." : "La federació us permet connectar-vos amb altres servidors de confiança per a intercanviar carpetes de compte. Per exemple, s'utilitzarà per a proporcionar resultats d'emplenament automàtic de comptes externs per a l'ús compartit federat.",
    "External documentation for Federated Cloud Sharing" : "Documentació externa per a compartició federada de núvol",
    "Federation allows you to connect with other trusted servers to exchange the account directory. For example this will be used to auto-complete external accounts for federated sharing. It is not necessary to add a server as trusted server in order to create a federated share." : "La federació us permet connectar-vos amb altres servidors de confiança per a intercanviar carpetes de compte. Per exemple, s'utilitzarà per a proporcionar resultats d'emplenament automàtic de comptes externs per a l'ús compartit federat. No cal afegir un servidor com a servidor de confiança per a crear un recurs d'ús compartit federat.",
    "Each server must validate the other. This process may require a few cron cycles." : "Cada servidor ha de validar l'altre. Aquest procés pot requerir uns quants cicles cron.",
    "+ Add trusted server" : "+ Afegeix un servidor de confiança",
    "Trusted server" : "Servidor de confiança",
    "Add" : "Afegeix"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-32.0.5-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/federation/l10n/ca.js <==
OC.L10N.register(
    "federation",
    {
    "Added to the list of trusted servers" : "S'ha afegit a la llista de servidors de confiança",
    "No server found with ID: %s" : "No s'ha trobat cap servidor amb ID: %s",
    "Could not remove server" : "No s'ha pogut suprimir el servidor",
    "Server is already in the list of trusted servers." : "El servidor ja es troba en la llista de servidors de confiança.",
    "No server to federate with found" : "No s'ha trobat cap servidor amb què federar-se",
    "Could not add server" : "No s'ha pogut afegir el servidor",
    "Trusted servers" : "Servidors de confiança",
    "Federation" : "Federació",
    "Federation allows you to connect with other trusted servers to exchange the account directory." : "La federació us permet connectar-vos amb altres servidors de confiança per a intercanviar la carpeta del compte.",
    "Federation allows you to connect with other trusted servers to exchange the account directory. For example this will be used to auto-complete external accounts for federated sharing." : "La federació us permet connectar-vos amb altres servidors de confiança per a intercanviar carpetes de compte. Per exemple, s'utilitzarà per a proporcionar resultats d'emplenament automàtic de comptes externs per a l'ús compartit federat.",
    "Add" : "Afegeix",
    "Delete" : "Suprimir",
    "Federation allows you to connect with other trusted servers to exchange the account directory. For example this will be used to auto-complete external accounts for federated sharing. It is not necessary to add a server as trusted server in order to create a federated share." : "La federació us permet connectar-vos amb altres servidors de confiança per a intercanviar carpetes de compte. Per exemple, s'utilitzarà per a proporcionar resultats d'emplenament automàtic de comptes externs per a l'ús compartit federat. No cal afegir un servidor com a servidor de confiança per a crear un recurs d'ús compartit federat.",
    "Each server must validate the other. This process may require a few cron cycles." : "Cada servidor ha de validar l'altre. Aquest procés pot requerir uns quants cicles cron.",
    "External documentation for Federated Cloud Sharing" : "Documentació externa per a compartició federada de núvol",
    "+ Add trusted server" : "+ Afegeix un servidor de confiança",
    "Trusted server" : "Servidor de confiança"
},
"nplurals=2; plural=(n != 1);");
